import { Environment, Implementation, WidgetData, ImplementationConfiguration, ImplementationSelector, ConfigureCallback } from '@webprovisions/platform';
import TriggerElementMonitor from './trigger-element-monitor';
export declare function attach(widget: WidgetData, ...triggerElements: HTMLElement[]): Promise<WidgetData>;
export declare function scan(implementation: BootstrappedImplementation, rootElement?: HTMLElement | Document): Promise<WidgetData[]>;
export declare type ConfigurationHandler = (...args: any[]) => void;
export interface BootstrappedEnvironment extends Environment {
    /**
     * Extension method for configuring one or many implementations in the current `Environment`.
     */
    configure: (selectorOrConfigFn: (ImplementationSelector | ConfigureCallback), configFn?: ConfigureCallback) => void;
}
export interface BootstrappedImplementationConfiguration extends ImplementationConfiguration {
    bindings: string[];
}
/**
 * A bootstrapped `Implementation` with additional extension methods.
 */
export interface BootstrappedImplementation extends Implementation {
    /**
     * Array of domain names to identify during the bootstrapping.
     */
    bindings: string[];
    environment: BootstrappedEnvironment;
    /**
     * Scans the document, or the specified container element, for trigger elements.
     */
    scan: (rootElement?: HTMLElement | Document) => Promise<WidgetData[]>;
    /**
     * Attaches a `WidgetData` instance to additional trigger elements.
     */
    attach: (widget: WidgetData, ...triggerElements: HTMLElement[]) => Promise<WidgetData>;
}
export declare type BootstrappingData = {
    /**
     * Indicates whether the current implementation has been fully bootstrapped.
     */
    ready: boolean;
    /**
     * Monitors trigger elements and dispatches event when new elements are detected.
     */
    monitor: TriggerElementMonitor;
};
/**
 * Bootstraps an implementation by scanning the document, or the specified root element, for
 * trigger elements, and enables the default bootstrapping capabilities in supported widgets.
 * @param implementation Implementation to bootstrap.
 * @param createConfigurationHandlers Function for supplying default configuration handlers.
 * @param rootElementResolver Function for resolving the root element.
 */
export default function bootstrapImplementation(implementation: Implementation, bindings: string[], createConfigurationHandlers: () => ConfigurationHandler[], rootElementResolver: (() => HTMLElement)): Promise<BootstrappedImplementation>;
